#
# spec file for package vkmark
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2018-2022 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vkmark
Version:        2025.01+git.20250317
Release:        1.2
Summary:        Vulkan benchmark utility
License:        LGPL-2.1-or-later
URL:            https://github.com/vkmark/vkmark
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  glm-devel
BuildRequires:  meson >= 0.45
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(assimp)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-icccm)
ExcludeArch:    %{arm} %{ix86}

%description
An extensible Vulkan benchmarking suite with targeted, configurable scenes.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%files
%{_bindir}/vkmark
%{_libdir}/vkmark/
%{_mandir}/man1/vkmark.1%{?ext_man}
%{_datadir}/vkmark/

%changelog
* Wed Apr  9 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 2025.01+git.20250317:
  * build: Enable precompiled headers
  * scenes/shading: Add missing fragment stage flag for uniform descriptor set
  * display: Properly handle Vulkan errors during probing
  * scenes: Use dedicated uniform buffer per image when needed
  * kms: Specify modifier for DRM framebuffers when possible
  * kms: Use the implicit modifier gbm API when only INVALID is supported
  * kms: Get modifiers from the primary plane compatible with the used crtc
  * kms: Fix modifier support for legacy modesetting
  * Update files for 2025.01 release
  * core: Use integer arithmetic to calculate average scene FPS
  * kms: Allow TRANSFER_DST usage for created images
  * kms: Require VK_KHR_display and VK_KHR_surface
  * kms: Remove commented out debugging message
  * kms: Support immediate presentation mode
  * kms: Support mailbox presentation mode
  * kms: Throw exception on page flip failure
  * kms: Deduplicate image presentation code
  * kms: Use image queue submit fences to synchronize presentation
  * core,scenes: Allow backends to support an image queue submit fences
  * scenes: Use a vkQueueSubmit signal semaphore only if the backend supports them
  * core: Show display information when listing physical devices
  * core: List Vulkan devices without initializing all Vulkan state
  * display: Add 'display-index' winsys option
  * display: Add window system that uses VK_KHR_display
  * build: Add vulkan dependency to headless window system plugin
  * ws: Centralize window system priority defines
  * core: Use std::optional for use_device_with_uuid option
  * ws: NativeSystem required_extensions
  * kms: Add missing VK_KHR_dedicated_allocation extension request
* Wed Jan 15 2025 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20250114:
  * kms: Create gbm_bos with explicit modifiers if possible
  * kms: Explicitly request all extensions dependencies
  * github: Add ubuntu-24.04 build in CI
  * headless: Add plugin for a headless window system
  * ws: Resolve swapchain related validation errors
  * vulkan_state: Set application vulkan version
  * vulkan_state: Add support for validation layers
  * build: Generate format names map from vk.xml
  * scenes,ws: Silence [[nodiscard]] warnings
  * kms: Add winsys option to specify the TTY to use
  * kms: Unbreak on FreeBSD
  * xcb: Fix incorrect window hint size
  * kms: Probe and use the first functional /dev/dri/cardX device
  * build: Require C++17
  * wayland: Avoid segfault after failure to connect to display server
  * kms: Gracefully handle null results from KMS functions
  * ws: Improve automatic window system selection
* Thu Jun 15 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20230412:
  * kms: Use VK_EXT_external_memory_dmabuf to create dmabuf-backed Vulkan images
  * core,ws: Allow WSI backends to request device extensions
  * core: Improve log message consistency
  * github: Build with both ubuntu-20.04 and ubuntu-22.04 in CI
  * vkutil: transition image to eShaderReadOnlyOptimal
  * Fix missing <cstdint> include
- Drop no longer needed vkmark-cstdint-include.patch
* Tue Mar 28 2023 malcolmlewis@opensuse.org
- Add vkmark-cstdint-include.patch: Add missing cstdint include in
  scene.h, (gh#vkmark/vkmark#51).
* Thu Feb  2 2023 malcolmlewis@opensuse.org
- Drop build requires on deprecated Mesa-libVulkan-devel.
* Thu Nov 24 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20220909:
  * Fix missing <memory> includes
- Drop vkmark-fix-missing-include.patch
* Fri Sep  9 2022 malcolmlewis@opensuse.org
- Add vkmark-fix-missing-include.patch: Add missing memory include
  to fix building.
* Tue Jun 28 2022 malcolmlewis@opensuse.org
- Update to version 2017.08+git.20220516:
  * vkutil: Fix compilation with older vulkan-hpp versions
  * vkutil: Avoid deprecated vk::ResultValue implicit cast
  * tests: Update catch.hpp to v2.13.9
- Drop vkmark-sigstksz-not-constant.patch as this is upstreamed.
* Mon Dec 20 2021 malcolmlewis@opensuse.org
- Add vkmark-sigstksz-not-constant.patch: Temporary fix for glibc
  changes, (gh#vkmark/vkmark#37).
* Wed Oct 20 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20211008:
  * meson: check all deps, when enabling wayland winsys
  * meson: error out when no winsys is available
* Thu Apr 22 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20210312:
  * wayland: Reply to ping message
* Thu Mar  4 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20210301:
  * doc: Document new Vulkan device related flags in man page
  * core: Allow selecting the Vulkan device to run on
* Fri May 22 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2017.08+git.20200521:
  * core: Use generated map of pixel formats to handle --pixel-format option
  * core: Fix crash with newer vulkan-hpp
  * doc: Update README.md with new wayland dependencies
  * ci: Update packages dependencies for wayland
  * wayland: Port to xdg-shell
  * wayland: Mark the whole surface as opaque
  * wayland: Retain native size in hidpi scaled outputs
  * ci: Add build and test github workflow
  * Fix build against glm-0.9.9.6
  * build: Specify meson version as 0.45
* Thu Dec 19 2019 Martin Pluskal <mpluskal@suse.com>
- Update dependencies (add Mesa-libVulkan-devel)
* Sun Nov 24 2019 malcolmlewis@opensuse.org
- Update to version 2017.08+git.20191115:
  * ci: Add build and test github workflow.
  * Fix build against glm-0.9.9.6.
  * build: Specify meson version as 0.45.
  * kms: Check the result of the vkCreateDmaBufImageINTEL call.
  * kms: Add kms-atomic window system option.
  * kms: Add atomic modesetting support.
  * kms: Simplify creation of ManagedResource objects.
  * scenes: Use vkutil::map_memory.
  * vkutil: Add map_memory helper function.
  * scenes: Use vkutil::SemaphoreBuilder.
- Drop vkmark-skip-glm-dep-check.patch as this has been upstreamed.
* Tue Nov  5 2019 Martin Pluskal <mpluskal@suse.com>
- Do not try to build on 32 bit architectures
* Wed Nov 14 2018 Martin Pluskal <mpluskal@suse.com>
- Small packaging cleanups
* Tue Nov 13 2018 malcolmlewis@opensuse.org
- Initial build at version 2017.08 up to commit
  1ebd493 (2018-05-30).
- Add vkmark-skip-glm-dep-check.patch: No glm-devel pc file
  present in development package, so check fails.
